# This file was generated by symflow CLI vSYM_TEMPLATE_VAR_SYMFLOW_VERSION on SYM_TEMPLATE_VAR_GENERATION_TIME UTC.
# No changes to this file are required to start managing your Okta access with Sym.
# Modify this file to customize your Okta access management, or add more Okta Groups to be managed.


# The Okta Integration that your Sym Strategy uses to manage your Okta targets
resource "sym_integration" "SYM_TEMPLATE_VAR_FLOW_RESOURCE_NAME_okta" {
  type        = "okta"
  name        = "SYM_TEMPLATE_VAR_FLOW_NAME-okta-integration"
  external_id = "SYM_TEMPLATE_VAR_OKTA_DOMAIN"

  settings = {
    # `type=okta` sym_integrations have a required setting `api_token_secret`,
    # which must point to a sym_secret referencing your Okta API Key
    api_token_secret = sym_secret.SYM_TEMPLATE_VAR_FLOW_RESOURCE_NAME_okta_api_key.id
  }
}

# An AWS Secrets Manager Secret to hold your Okta API Key. Set the value with:
# aws secretsmanager put-secret-value --secret-id "sym/SYM_TEMPLATE_VAR_FLOW_NAME/okta-api-key" --secret-string "YOUR-OKTA-API-KEY"
resource "aws_secretsmanager_secret" "SYM_TEMPLATE_VAR_FLOW_RESOURCE_NAME_okta_api_key" {
  name        = "sym/SYM_TEMPLATE_VAR_FLOW_NAME/okta-api-key"
  description = "API Key for Sym to call Okta APIs"

  tags = {
    # This SymEnv tag is required because the aws_iam_policy.secrets_manager_access from secrets.tf
    # only grants access to secrets tagged with a matching SymEnv value
    SymEnv = local.environment_name
  }
}

# This resource tells Sym how to access your Okta API Key.
resource "sym_secret" "SYM_TEMPLATE_VAR_FLOW_RESOURCE_NAME_okta_api_key" {
  # The source of your secrets and the permissions needed to access
  # i.e. AWS Secrets Manager, access with IAM Role.
  source_id = sym_secrets.this.id

  # Name of the key in AWS Secrets Manager
  path = aws_secretsmanager_secret.SYM_TEMPLATE_VAR_FLOW_RESOURCE_NAME_okta_api_key.name
}

# A target Okta group that your Sym Strategy can manage access to
resource "sym_target" "SYM_TEMPLATE_VAR_FLOW_RESOURCE_NAME_okta_group" {
  type = "okta_group"
  name = "SYM_TEMPLATE_VAR_FLOW_NAME-okta-group"

  settings = {
    # `type=okta_group` sym_targets have a required setting `group_id`,
    # which must be the Group ID the requester will be escalated to when this target is selected.

    # The GroupID is visible while in the Okta Admin console, with the Group selected, in the URL of the browser.
    # Directory > Groups > Select the Group > the ID at the end of the browser's URL.
    group_id = "SYM_TEMPLATE_VAR_OKTA_GROUP_ID"
  }
}

# The Strategy your Flow uses to escalate to Okta Groups
resource "sym_strategy" "SYM_TEMPLATE_VAR_FLOW_RESOURCE_NAME_okta" {
  type           = "okta"
  name           = "SYM_TEMPLATE_VAR_FLOW_NAME-okta-strategy"
  integration_id = sym_integration.SYM_TEMPLATE_VAR_FLOW_RESOURCE_NAME_okta.id

  # This must be a list of `okta_group` sym_target that users can request to be escalated to
  targets = [sym_target.SYM_TEMPLATE_VAR_FLOW_RESOURCE_NAME_okta_group.id]
}

resource "sym_flow" "SYM_TEMPLATE_VAR_FLOW_RESOURCE_NAME_okta" {
  name  = "SYM_TEMPLATE_VAR_FLOW_NAME-okta"
  label = "Okta Group Access"

  implementation = "${path.module}/impls/SYM_TEMPLATE_VAR_FLOW_RESOURCE_NAME_okta_impl.py"
  environment_id = sym_environment.this.id

  params {
    # By specifying a strategy, this Flow will now be able to manage access (escalate/de-escalate)
    # to the targets specified in the `sym_strategy` resource.
    strategy_id = sym_strategy.SYM_TEMPLATE_VAR_FLOW_RESOURCE_NAME_okta.id

    # Each prompt_field defines a custom form field for the Slack modal that
    # requesters fill out to make their requests.
    prompt_field {
      name     = "reason"
      label    = "Why do you need access?"
      type     = "string"
      required = true
    }

    prompt_field {
      name           = "duration"
      type           = "duration"
      allowed_values = ["30m", "1h"]
      required       = true
    }
  }
}
